PALM-meteo: palmmeteo_stdplugins.winddamp.WindDampPlugin Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo_stdplugins.winddamp.WindDampPlugin Class Reference
Inheritance diagram for palmmeteo_stdplugins.winddamp.WindDampPlugin:
[legend]
Collaboration diagram for palmmeteo_stdplugins.winddamp.WindDampPlugin:
[legend]

## Public Member Functions
| __init__ (self)
| check_config (self, *args, **kwargs)
| write_data (self, fout, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
| __new__ (cls, name, bases, dct)

## Public Attributes
| stagger

## Detailed Description

    A plugin which provides damping of wind near vertical walls in the initial
    conditions. This helps to avoid instabilities in the pressure solver in the
    first timestep.

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo_stdplugins.winddamp.WindDampPlugin.__init__ | ( |  | self | ) |

## Member Function Documentation

## ◆ check_config()

palmmeteo_stdplugins.winddamp.WindDampPlugin.check_config | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

    (Load and) validate plugin-related configuration.

    Any plugin can optinally implement the check_config method for
    validating configuration. It is not required, so the method is not
    abstract.

Reimplemented from palmmeteo.plugins.Plugin.

## ◆ write_data()

palmmeteo_stdplugins.winddamp.WindDampPlugin.write_data | ( |  | self,
|  |  | fout,
|  | * | args,
|  | ** | kwargs
| ) |  |

    Decrease the written initial condition wind using a calculated factor.
    Exactly num_zeroed cells outside the wall will have a factor of 0, then
    linearly inceasing and all cells beyond damping_dist will have a factor
    of 1.

Reimplemented from palmmeteo.plugins.WritePluginMixin.

## Member Data Documentation

## ◆ stagger

palmmeteo_stdplugins.winddamp.WindDampPlugin.stagger

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/winddamp.py